@@ -6,7 +6,7 @@ require Scalar::Util;
 require Symbol;
 use Moo::Role;
 
-our $VERSION= '0.07';
+our $VERSION= '0.08';
 our @CARP_NOT= qw( DataStore::CAS::File DataStore::CAS::VirtualHandle );
 
 # ABSTRACT: Abstract base class for Content Addressable Storage
@@ -241,32 +241,34 @@ package DataStore::CAS::File;
 use strict;
 use warnings;
 
-our $VERSION= '0.07';
+our $VERSION= '0.08';
 
-sub store { $_[0]{store} }
+sub cas { $_[0]{store} }
+*store= *cas; # back-compat
 sub hash  { $_[0]{hash} }
 sub size  { $_[0]{size} }
 
 sub open {
 	my $self= shift;
-	return $self->{store}->open_file($self)
+	return $self->cas->open_file($self)
 		if @_ == 0;
-	return $self->{store}->open_file($self, { @_ })
+	return $self->cas->open_file($self, { @_ })
 		if @_ > 1;
-	return $self->{store}->open_file($self, { layer => $_[0] })
+	return $self->cas->open_file($self, { layer => $_[0] })
 		if @_ == 1 and !ref $_[0];
 	Carp::croak "Wrong arguments to 'open'";
 };
 
 sub DESTROY {
-	$_[0]{store}->_file_destroy(@_);
+	my $cas= $_[0]->cas;
+	$cas->_file_destroy(@_) if defined $cas; # simple guard against global destruction
 }
 
 our $AUTOLOAD;
 sub AUTOLOAD {
 	my $attr= substr($AUTOLOAD, rindex($AUTOLOAD, ':')+1);
 	return $_[0]{$attr} if exists $_[0]{$attr};
-	unshift @_, $_[0]{store};
+	unshift @_, $_[0]->cas;
 	goto (
 		$_[0]->can("_file_$attr")
 		or Carp::croak "Can't locate object method \"_file_$attr\" via package \"".ref($_[0]).'"'
@@ -277,24 +279,28 @@ package DataStore::CAS::VirtualHandle;
 use strict;
 use warnings;
 
-our $VERSION= '0.07';
+our $VERSION= '0.08';
 
 sub new {
 	my ($class, $cas, $fields)= @_;
 	my $glob= bless Symbol::gensym(), $class;
 	${*$glob}= $cas;
-	%{*$glob}= %{$fields||{}};
+	%{*$glob}= %$fields if defined $fields;
 	tie *$glob, $glob;
 	$glob;
 }
 sub TIEHANDLE { return $_[0]; }
 
-sub _cas  { ${*${$_[0]}} }  # the scalar view of the symbol points to the CAS object
+sub cas { ${*${$_[0]}} }  # the scalar view of the symbol points to the CAS object
+*_cas= *cas; # back-compat
 sub _data { \%{*${$_[0]}} } # the hashref view of the symbol holds the fields of the handle
 
-sub DESTROY { unshift @_, ${*{$_[0]}}; goto $_[0]->can('_handle_destroy') }
+sub DESTROY {
+	my $cas= $_[0]->cas;
+	$cas->_handle_destroy(@_) if defined $cas; # simple guard against global destruction
+}
 
-# By default, any method not defined will call to C<$cas->_handle_$method( $handle, @args );>
+# By default, any method not defined will call to $cas->_handle_$method( $handle, @args );
 our $AUTOLOAD;
 sub AUTOLOAD {
 	unshift @_, ${*${$_[0]}}; # unshift @_, $self->_cas
@@ -380,7 +386,7 @@ use strict;
 use warnings;
 use parent -norequire => 'DataStore::CAS::VirtualHandle';
 
-our $VERSION= '0.07';
+our $VERSION= '0.08';
 
 # For write-handles, commit data to the CAS and return the digest hash for it.
 sub commit   { $_[0]->_cas->commit_write_handle(@_) }
@@ -412,7 +418,7 @@ DataStore::CAS - Abstract base class for Content Addressable Storage
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
@@ -846,7 +852,7 @@ Michael Conrad <mconrad@intellitree.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022 by Michael Conrad, and IntelliTree Solutions llc.
+This software is copyright (c) 2023 by Michael Conrad, and IntelliTree Solutions llc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
