@@ -1,6 +1,6 @@
 package DataStore::CAS::CatalystControllerSimpleCASAdapter;
 
-our $VERSION= '0.07';
+our $VERSION= '0.08';
 #ABSTRACT: Moo Role providing compatibility for Catalyst::Controller::SimpleCAS
 
 
@@ -9,6 +9,10 @@ use Moo::Role;
 
 requires qw( get calculate_hash calculate_file_hash put_scalar put_file );
 
+# SimpleCAS passes this argument, and our constructor checks for unknown
+# arguments, so just store it in a weak attribute.
+has simplecas => ( is => 'rw', weak_ref => 1 );
+
 sub content_exists {
 	my ($self, $checksum)= @_;
 	return !!$self->get($checksum);
@@ -79,7 +83,7 @@ DataStore::CAS::CatalystControllerSimpleCASAdapter - Moo Role providing compatib
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
@@ -116,7 +120,7 @@ Michael Conrad <mconrad@intellitree.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022 by Michael Conrad, and IntelliTree Solutions llc.
+This software is copyright (c) 2023 by Michael Conrad, and IntelliTree Solutions llc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
