@@ -8,7 +8,7 @@ use File::Spec 3.33;
 use File::Spec::Functions 'catfile', 'catdir', 'canonpath';
 use File::Temp 0.22 ();
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 our @CARP_NOT= qw( DataStore::CAS DataStore::CAS::File DataStore::CAS::VirtualHandle );
 
 # ABSTRACT: Simple file/directory based CAS implementation
@@ -33,7 +33,7 @@ sub BUILD {
 
 	# Check for invalid params
 	my @inval= grep { !$self->can($_) } keys %$args;
-	croak "Invalid parameter: ".join(', ', @inval)
+	carp "Invalid parameter: ".join(', ', @inval)
 		if @inval;
 
 	# Path is required, and must be a directory
@@ -641,7 +641,7 @@ DataStore::CAS::Simple - Simple file/directory based CAS implementation
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 DESCRIPTION
 
@@ -834,7 +834,7 @@ Michael Conrad <mconrad@intellitree.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022 by Michael Conrad, and IntelliTree Solutions llc.
+This software is copyright (c) 2023 by Michael Conrad, and IntelliTree Solutions llc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
